##' The \pkg{gWidgets2} package provides a programming interface for
##' making graphical user interfaces within R. The package is a
##' rewrite of the \pkg{gWidgets} package, introducing a few external
##' changes but a significant number of internal ones. The package
##' relies on one of several underlying toolkit packages providing
##' access to the graphical libraries. This package provides the
##' implementation to interface with the underlying \pkg{tcltk}
##' package.
##' 
##' @author
##' John Verzani \email{jverzani@@gmail.com}
##'
##' Maintainer: John Verzani \email{jverzani@@gmail.com}
##' @param ... passed to constructor
##' @aliases gWidgets2tcltk-package
##' @name gWidgets2tcltk-package
##' @docType package
##' @title gWidgets2tcltk
##' @keywords package
NULL

##' @import tcltk
##' @import digest
##' @import memoise
##' @import methods
NULL

tclVar <- tcltk::tclVar
tclObj <- tcltk::tclObj
